@@ -157,7 +157,7 @@ def _checkargs(time, status, entry, freq_weights, exog):
         raise ValueError("the rows of exog should align with time")
 
 
-class CumIncidenceRight(object):
+class CumIncidenceRight:
     """
     Estimation and inference for a cumulative incidence function.
 
@@ -260,7 +260,7 @@ class CumIncidenceRight(object):
         self.title = "" if not title else title
 
 
-class SurvfuncRight(object):
+class SurvfuncRight:
     """
     Estimation and inference for a survival function.
 
@@ -457,7 +457,7 @@ class SurvfuncRight(object):
             g = lambda x: x
             gprime = lambda x: 1
         elif method == "log":
-            g = lambda x: np.log(x)
+            g = np.log
             gprime = lambda x: 1 / x
         elif method == "logit":
             g = lambda x: np.log(x / (1 - x))
@@ -764,7 +764,7 @@ def plot_survfunc(survfuncs, ax=None):
     >>> ax = fig.get_axes()[0]
     >>> ax.set_position([0.1, 0.1, 0.64, 0.8])
     >>> ha, lb = ax.get_legend_handles_labels()
-    >>> leg = fig.legend((ha[0], ha[1]), (lb[0], lb[1]), 'center right')
+    >>> leg = fig.legend((ha[0], ha[1]), (lb[0], lb[1]), loc='center right')
 
     Change the line colors:
 
@@ -781,7 +781,7 @@ def plot_survfunc(survfuncs, ax=None):
     # If we have only a single survival function to plot, put it into
     # a list.
     try:
-        assert(type(survfuncs[0]) is SurvfuncRight)
+        assert type(survfuncs[0]) is SurvfuncRight
     except:
         survfuncs = [survfuncs]
 
